==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/panel/translations/razor-panel_el_GR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="el_GR">
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <location filename="../configpaneldialog.ui" line="14"/>
        <source>Configure panel</source>
        <translation>Ρύθμιση πίνακα</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="20"/>
        <source>Panel size</source>
        <translation>Μέγεθος πίνακα</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="26"/>
        <source>Size:</source>
        <translation>Μέγεθος:</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="33"/>
        <location filename="../configpaneldialog.ui" line="115"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="43"/>
        <source>Use theme size</source>
        <translation>Χρήση μεγέθους θέματος</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="60"/>
        <source>Panel lenght &amp; position</source>
        <translation>Μήκος &amp; θέση πίνακα</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="73"/>
        <source>Length:</source>
        <translation>Μήκος:</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="80"/>
        <source>Alignment:</source>
        <translation>Στοίχιση:</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="91"/>
        <source>Left</source>
        <translation>Αριστερά</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="96"/>
        <source>Center</source>
        <translation>Κέντρο</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="101"/>
        <source>Right</source>
        <translation>Δεξιά</translation>
    </message>
    <message>
        <location filename="../configpaneldialog.ui" line="110"/>
        <source>%</source>
        <translation>%</translation>
    </message>
</context>
<context>
    <name>PositionAction</name>
    <message>
        <location filename="../razorpanel.cpp" line="578"/>
        <source>Top of desktop</source>
        <translation>Επάνω στην επιφάνεια εργασίας</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="579"/>
        <source>Bottom of desktop</source>
        <translation>Κάτω στην επιφάνεια εργασίας</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="580"/>
        <source>Left of desktop</source>
        <translation>Αριστερά στην επιφάνεια εργασίας</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="581"/>
        <source>Right of desktop</source>
        <translation>Δεξιά στην επιφάνεια εργασίας</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="588"/>
        <source>Top of desktop %1</source>
        <translation>Επάνω στην επιφάνεια εργασίας %1</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="589"/>
        <source>Bottom of desktop %1</source>
        <translation>Κάτω στην επιφάνεια εργασίας %1</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="590"/>
        <source>Left of desktop %1</source>
        <translation>Αριστερά στην επιφάνεια εργασίας %1</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="591"/>
        <source>Right of desktop %1</source>
        <translation>Δεξιά στην επιφάνεια εργασίας %1</translation>
    </message>
</context>
<context>
    <name>RazorPanelPluginPrivate</name>
    <message>
        <location filename="../razorpanelplugin.cpp" line="149"/>
        <source>Configure</source>
        <translation>Ρύθμιση</translation>
    </message>
    <message>
        <location filename="../razorpanelplugin.cpp" line="154"/>
        <source>Move</source>
        <translation>Μετακίνηση</translation>
    </message>
    <message>
        <location filename="../razorpanelplugin.cpp" line="160"/>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
</context>
<context>
    <name>RazorPanelPrivate</name>
    <message>
        <location filename="../razorpanel.cpp" line="832"/>
        <source>Panel</source>
        <translation>Πίνακας</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="843"/>
        <source>Plugins</source>
        <translation>Πρόσθετα</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="845"/>
        <source>Add plugins ...</source>
        <translation>Προσθήκη προσθέτων ...</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="854"/>
        <source>Move plugin</source>
        <translation>Μετακίνηση πρόσθετου</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="860"/>
        <source>Configure plugin</source>
        <translation>Ρύθμιση πρόσθετου</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="867"/>
        <source>Delete plugin</source>
        <translation>Διαγραφή πρόσθετου</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="874"/>
        <source>Show this panel at</source>
        <translation>Εμφάνιση αυτού του πίνακα στο</translation>
    </message>
    <message>
        <location filename="../razorpanel.cpp" line="917"/>
        <source>Configure panel</source>
        <translation>Ρύθμιση πίνακα</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/panel/translations/razor-panel_el_GR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="el_GR" version="2.0">
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <source>Configure panel</source>
        <translation>Διαμόρφωση πίνακα</translation>
    </message>
    <message>
        <source>Panel size</source>
        <translation>Μέγεθος πίνακα</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Μέγεθος:</translation>
    </message>
    <message>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <source>Use automatic sizing</source>
        <translation>Χρήση αυτόματου μεγέθους</translation>
    </message>
    <message>
        <source>Panel length &amp;&amp; position</source>
        <translation>Μήκος &amp;&amp; θέση πίνακα</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Αριστερά</translation>
    </message>
    <message>
        <source>Center</source>
        <translation>Κέντρο</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Δεξιά</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Alignment:</source>
        <translation>Στοίχιση:</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Μήκος:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Θέση:</translation>
    </message>
    <message>
        <source>Top of desktop</source>
        <translation>Επάνω στην επιφάνεια εργασίας</translation>
    </message>
    <message>
        <source>Left of desktop</source>
        <translation>Αριστερά στην επιφάνεια εργασίας</translation>
    </message>
    <message>
        <source>Right of desktop</source>
        <translation>Δεξιά στην επιφάνεια εργασίας</translation>
    </message>
    <message>
        <source>Bottom of desktop</source>
        <translation>Κάτω στην επιφάνεια εργασίας</translation>
    </message>
    <message>
        <source>Top of desktop %1</source>
        <translation>Επάνω στην επιφάνεια εργασίας %1</translation>
    </message>
    <message>
        <source>Left of desktop %1</source>
        <translation>Αριστερά στην επιφάνεια εργασίας %1</translation>
    </message>
    <message>
        <source>Right of desktop %1</source>
        <translation>Δεξιά στην επιφάνεια εργασίας %1</translation>
    </message>
    <message>
        <source>Bottom of desktop %1</source>
        <translation>Κάτω στην επιφάνεια εργασίας %1</translation>
    </message>
</context>
<context>
    <name>RazorPanel</name>
    <message>
        <source>Panel</source>
        <translation>Πίνακας</translation>
    </message>
    <message>
        <source>Configure panel...</source>
        <translation>Διαμόρφωση πίνακα...</translation>
    </message>
    <message>
        <source>Add plugins ...</source>
        <translation>Προσθήκη επεκτάσεων...</translation>
    </message>
</context>
<context>
    <name>RazorPanelPlugin</name>
    <message>
        <source>Configure</source>
        <translation>Διαμόρφωση</translation>
    </message>
    <message>
        <source>Move</source>
        <translation>Μετακίνηση</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Αφαίρεση</translation>
    </message>
</context>
<context>
    <name>RazorPanelPrivate</name>
    <message>
        <source>Configure panel</source>
        <translation>Διαμόρφωση πίνακα</translation>
    </message>
</context>
</TS>
